@@ -214,7 +214,7 @@ def option_czce_daily(
     :type trade_date: str
     :param symbol: choice of {"白糖期权", "棉花期权", "甲醇期权", "PTA期权", "动力煤期权", "菜籽粕期权", "菜籽油期权",
     "花生期权", "对二甲苯期权", "烧碱期权", "纯碱期权", "短纤期权", "锰硅期权", "硅铁期权", "尿素期权", "苹果期权", "红枣期权",
-    "玻璃期权", "瓶片期权"}
+    "玻璃期权", "瓶片期权", "丙烯期货"}
     :type symbol: str
     :return: 日频行情数据
     :rtype: pandas.DataFrame
@@ -368,6 +368,12 @@ def option_czce_daily(
                 temp_df = temp_df.iloc[:-1, :].copy()
                 new_df = __option_czce_daily_convert_numeric_columns(temp_df)
                 return new_df
+            elif symbol == "丙烯期货":
+                temp_df = table_df[table_df.iloc[:, 0].str.contains("PL")]
+                temp_df.reset_index(inplace=True, drop=True)
+                temp_df = temp_df.iloc[:-1, :].copy()
+                new_df = __option_czce_daily_convert_numeric_columns(temp_df)
+                return new_df
             else:
                 return pd.DataFrame()
         except:  # noqa: E722
@@ -630,11 +636,11 @@ def option_gfex_vol_daily(symbol: str = "碳酸锂", trade_date: str = "20230724
 
 
 if __name__ == "__main__":
-    option_czce_daily_df = option_czce_daily(symbol="白糖期权", trade_date="20170419")
+    option_czce_daily_df = option_czce_daily(symbol="丙烯期货", trade_date="20250812")
     print(option_czce_daily_df)
 
     option_dce_daily_one, option_dce_daily_two = option_dce_daily(
-        symbol="纯苯期权", trade_date="20250708"
+        symbol="纯苯期权", trade_date="20250814"
     )
     print(option_dce_daily_one)
     print(option_dce_daily_two)
@@ -657,7 +663,7 @@ if __name__ == "__main__":
     print(option_shfe_daily_one)
     print(option_shfe_daily_two)
 
-    option_gfex_daily_df = option_gfex_daily(symbol="工业硅", trade_date="20240102")
+    option_gfex_daily_df = option_gfex_daily(symbol="工业硅", trade_date="20250801")
     print(option_gfex_daily_df)
 
     option_gfex_vol_daily_df = option_gfex_vol_daily(
